# Sample code: Run eye glasses detection on two images (one image with eye glasses, one image without eye glasses)

import tfsdk
import os

options = tfsdk.ConfigurationOptions()
# Can set configuration options here
# ex:
# options.smallest_face_height = 40
# options.fd_mode = tfsdk.FACEDETECTIONMODE.VERSATILE
# options.fd_filter = tfsdk.FACEDETECTIONFILTER.BALANCED
# options.fr_model = tfsdk.FACIALRECOGNITIONMODEL.FULL

sdk = tfsdk.SDK(options)

# TODO: export your license token as TRUEFACE_TOKEN environment variable
is_valid = sdk.set_license(os.environ['TRUEFACE_TOKEN'])
if (is_valid == False):
    print("Invalid License Provided")
    print("Be sure to export your license token as TRUEFACE_TOKEN")
    quit()

# Load the image with glasses
res = sdk.set_image("../images/glasses.jpg")
if (res != tfsdk.ERRORCODE.NO_ERROR):
    print("Unable to set image 1")
    quit()

# detect the largest face
found, face_bounding_box = sdk.detect_largest_face()
if found:
    # Run glasses detection
    res, glasses_label = sdk.detect_glasses(face_bounding_box)
    if (res != tfsdk.ERRORCODE.NO_ERROR):
        print("Unable to run detect glasses with image 1")
        quit()

    # Expect the result to be "glasses"
    print("Face with glasses, predicted result:", glasses_label)

else:
    print("No face detected in image")

# Load the non glasses face image
res = sdk.set_image("../images/headshot.jpg")
if (res != tfsdk.ERRORCODE.NO_ERROR):
    print("Unable to set image 2")
    quit()

# detect the largest face
found, face_bounding_box = sdk.detect_largest_face()
if found:
    # Run glasses detection
    res, glasses_label = sdk.detect_glasses(face_bounding_box)
    if (res != tfsdk.ERRORCODE.NO_ERROR):
        print("Unable to run detect glasses with image 2")
        quit()

    # Expect the result to be "no glasses"
    print("Face without glasses, predicted result:", glasses_label)

else:
    print("No face detected in image")
